/**
 * module WYSIWYG (frames management)
 *
 * @author Evgueni V. Palchukovsky <epalchukovsky@swsoft.com>
 * @version $Id: modulewysiwyg_frames.js,v 1.3 2006/02/13 05:17:06 epalchukovsky Exp $
 * @since 2006/01/31
 * @package SiteBuilder
 * @subpackage modules API
 * @copyright (c) 2004-2006, SWsoft
 */

function ModuleWysiwygFrameManager(parent_, editor, content, cellFunc) {

	this.m_editor = editor;
	this.m_doc = content.document;

	this.AssignColors = function(backgroundColor, borderColor, iconWidth) {
		this.m_doc.getElementById("base").style.backgroundColor = borderColor;
		this.m_doc.getElementById("content").style.backgroundColor = backgroundColor;
		var bt = this.m_doc.getElementById("borderTop");
		bt.style.backgroundColor = backgroundColor;
		bt.style.width = iconWidth;
	}

	this.AssignFont = function(font, size, color) {
		var controls = this.m_doc.getElementsByTagName("TD");
		for (var i = 0; i<controls.length; ++i) {
			var style_ = controls[i].style;
			style_.fontFamily = font;
			style_.fontSize = size;
			style_.color = color;
		}
	}

	// Constuction:

	var contentTable = this.m_doc.getElementById("content");
	for (var i = 0; i<contentTable.rows.length; ++i) {
		var row = contentTable.rows[i];
		for (var j = 0; j<row.cells.length; ++j) {
			cellFunc(parent_, row.cells[j]);
		}
	}

}

function ModuleWysiwygPaletteManager(editor, content, cmd, defaultColor) {

	this.AssignColors = function(backgroundColor, borderColor, iconWidth) {
		this.m_manager.AssignColors(backgroundColor, borderColor, iconWidth);
	}

	this.AssignFont = function(font, size, color) {
		this.m_manager.AssignFont(font, size, color);
	}

	this._CellFunc = function(parent_, cell) {
		cell.id = cell.id!="defaultColor"
			?	cell.style.backgroundColor
			:	this.m_defaultColor;
		cell.onmouseover = function() {
			this.style.border = "1px dotted white";
			this.style.cursor = "default";
		}
		cell.onmouseout = function() {
			this.style.border = "1px solid gray";
		}
		cell.onclick = function() {
			parent_.UseColor(this);
		}
	}

	this.UseColor = function(control) {
		this.m_manager.m_editor.UseColor(control.id, this.m_cmd);
	}

	// Constuction:

	this.m_defaultColor = defaultColor;
	this.m_cmd = cmd;
	this.m_manager = new ModuleWysiwygFrameManager(
		this, editor, content, this._CellFunc);

}

function ModuleWysiwygSmilesManager(editor, content) {

	this.AssignColors = function(backgroundColor, borderColor, iconWidth) {
		this.m_manager.AssignColors(backgroundColor, borderColor, iconWidth);
	}

	this.AssignFont = function(font, size, color) {
		/*...*/
	}

	this._CellFunc = function(parent_, cell) {
		cell.onclick = function() {
			parent_.InsertImage(this);
		}
	}

	this.InsertImage = function(control) {
		var src_ = _moduleWysiwyg.GetImagesPath()+"smiles/"+control.id+".gif";
		this.m_manager.m_editor.InsertImage(src_, control.id, "smile", false);
	}

	// Constuction:

	this.m_manager = new ModuleWysiwygFrameManager(
		this, editor, content, this._CellFunc);

}
