/**
 * module WYSIWYG (class-editor)
 *
 * @author Evgueni V. Palchukovsky <epalchukovsky@swsoft.com>
 * @version $Id: modulewysiwygeditor.js,v 1.5 2006/02/21 10:53:35 abelyaev Exp $
 * @since 2006/01/31
 * @package SiteBuilder
 * @subpackage modules API
 * @copyright (c) 2004-2006, SWsoft
 */

var isModuleWysiwygEditorLoaded = false;
var ModuleWysiwygEditorOnLoad = '';

function ModuleWysiwygEditor(wysiwyg, id, moduleId) {

	///////////////////////////////////////////////////////////////////////////
	// Fields:

	this.m_moduleId = moduleId;

	this.m_myId = id;
	this.m_wysiwyg = wysiwyg;

	this.m_loaded = false;
	this.m_fields = Array();

	this.m_frame = null;
	this.m_editor = null;
	this.m_doc = null;
	this.m_sel = null;

	this.m_stylerToolbar = new Styler();

	this.m_framePalette = null;
	this.m_frameSmiles = null;

	this.m_ctrlToolbar = null;

	this.m_openedPaletteCmd = null;

	this.m_styles = Array();

	this.m_imagesSrcsBackup = Array();

	///////////////////////////////////////////////////////////////////////////
	// Props:

	this.GetId = function() {
		return this.m_myId;
	}

	this.IsFrameLoaded = function() {
		this.InitDocument();
		var dm = this._GetDesignModeParent();
		return (isModuleWysiwygEditorLoaded && (dm.body.className == 'editor'));
	}

	this.IsDesignModeOn = function() {
		var dm = this._GetDesignModeParent();
		return dm.designMode.toLowerCase()=="on";
	}

	this.SetDesignModeOn = function() {
		var dm = this._GetDesignModeParent();
		dm.designMode = "On";
	}

	///////////////////////////////////////////////////////////////////////////

	///////////////////////////////////////////////////////////////////////////
	// Methods:

	////////////////////
	// Document content:

	this.SetOriginalContent = function(content, readOnly) {
		var html = "<html>";
		html += "<head>";
		html += "<link rel=\"stylesheet\" type=\"text/css\" href=\""+this.m_wysiwyg.GetCss()+"\">";
		html += "<body class=\"pageContent\" style=\"background-color:transparent; margin-left: 1px; margin-top: 0px; margin-right: 0px; margin-bottom: 0px;\">";
		html += content;
		html += "</body>";
		html += "</html>";
		if (this.m_wysiwyg.IsGecko()) {
			setTimeout("ModuleWysiwygEditorFill('"+this.GetId()+"', '"+html+"', "+readOnly+", 100);", 100);
		} else {
			ModuleWysiwygEditorFill(this.GetId(), html, readOnly, 0);
		}
		return true;
	}

	this.AttachField = function(fieldId, getContent, readOnly) {
		var result = false;
		var f = document.getElementById(fieldId);
		if (f) {
			result = !getContent || this.SetOriginalContent(f.value, readOnly);
		}
		if (result) {
			this.m_fields.push(fieldId);
		}
		return result;
	}

	this.SetPaletteFrame = function(frameId) {
		this.m_framePalette = document.getElementById(frameId);
		if (this.m_framePalette) {
			this.m_framePalette.src = this.m_wysiwyg.GetIncludesPath()+"palette.php";
		}
	}

	this.SetSmilesFrame = function(frameId) {
		this.m_frameSmiles = document.getElementById(frameId);
		if (this.m_frameSmiles) {
			this.m_frameSmiles.src = this.m_wysiwyg.GetIncludesPath()+"smiles.htm";
		}
	}

	this.SetToolbar = function(objectId) {
		this.m_ctrlToolbar = document.getElementById(objectId);
		if (this.m_ctrlToolbar) {
			this.m_stylerToolbar.ReadStyle(this.m_ctrlToolbar);
		}
	}

	///////////
	// Result:

	this.Submit = function() {
		if (!this.IsDesignModeOn()) {
			return true;
		} else if (!this.m_wysiwyg.IsReady()) {
			return false;
		}
		for (var i = 0; i<this.m_imagesSrcsBackup.length; ++i) {
			var backup = this.m_imagesSrcsBackup[i];
			var img = this.m_doc.getElementById(backup.id);
			if (img && img.tagName=="IMG") {
				img.src = backup.src;
			}
		}
		var xhtml = get_xhtml(this.m_doc.body, this.m_wysiwyg.GetLanguage(), this.m_wysiwyg.GetEncoding);
		xhtml = xhtml.replace(/\r\n/g, " ");
		xhtml = xhtml.replace(/\n/g, " ");
		xhtml = xhtml.replace(/\r/g, " ");
		xhtml = Trim(xhtml);
		var empty = 	StripHtml(xhtml.replace("&#160;", " "))==""
					&&	xhtml.toLowerCase().search("<hr")==-1
					&&	xhtml.toLowerCase().search("<img")==-1;
		if (empty) {
			xhtml = "";
		}
		return this._SaveToFields(xhtml);
	}

	///////////////////
	// Editor methods:

	this.UseFont = function(control, cmd) {
		selectedIndex_ = control.selectedIndex;
		if (selectedIndex_!=0) {
			this.ExecCommand(cmd, control.options[selectedIndex_].value);
			control.selectedIndex = 0;
		}
	}

	this.UseColor = function(color, cmd) {
		if (document.all) {
			this.m_sel.select();
		}
		this.ExecCommand(cmd, color);
	}

	this.InsertImage = function(src_, alt, class_, uploaded) {
		if (uploaded) {
			src_ = this.m_wysiwyg.GetIncludesPath()+'image.php?file='+src_;
		}
		class_ = class_ ? ' class="'+class_+'"' : '';
		var html = '<img src="'+src_+'" alt="'+alt+'"'+class_+'>';
		this.InsertHtml(html);
	}

	this.InsertHtml = function(html) {
		this.HideAll();
		try {
			this.m_editor.focus();
			if (document.all) {
				var sel = this.m_doc.selection.createRange();
				sel.pasteHTML(html);
				sel.collapse(false);
				sel.select();
			} else {
				this.m_doc.execCommand("insertHTML", false, html);
			}
		} catch (e) {
			alert("Error inserting HTML \""+e+"\".");
		}
	}

	this.ExecCommand = function(cmd, option) {
		this.HideAll();
		try {
			this.m_editor.focus();
	  		this.m_doc.execCommand(cmd, false, option);
			this.m_editor.focus();
		} catch (e) {
			alert(e);
		}
	}

	this.ShowHidePaletteForecolor = function(control) {
		return this._ShowHidePalette(control,  "forecolor");
	}
	this.ShowHidePaletteBackground = function(control) {
		return this._ShowHidePalette(control, document.all ? "backcolor" : "hilitecolor");
	}
	this.HidePalette = function() {
		this._HideFrame(this.m_framePalette);
		this.m_openedPaletteCmd = null;
	}

	this.ShowHideSmiles = function(parentControl) {
		if (this.m_frameSmiles && this._SetRange()) {
			var manager = new ModuleWysiwygSmilesManager(
				this, this.m_frameSmiles.contentWindow);
			if (this._ShowFrame(this.m_frameSmiles, parentControl, manager)) {
				return true;
			} else {
				this.HideSmiles();
			}
		}
		return false;
	}

	this.HideSmiles = function() {
		this._HideFrame(this.m_frameSmiles);
	}

	this.ShowHideInsertImage = function() {
		this._SetRange();
		InsertImage = PopUpWin(
			this.m_wysiwyg.GetIncludesPath()+'insert_image.php',
			'InsertImage', 360, 180, '');
		SetImageId(this.GetId(), this.m_moduleId);
	}



	this.ShowHideInsertLink = function() {
		InsertLink = PopUpWin(
			this.m_wysiwyg.GetIncludesPath()+'insert_link.htm',
			'InsertLink', 360, 180, '');
		this._SetRange();
		var linkText = StripHtml(this.m_wysiwyg.IsIe()
			?	this.m_sel.htmlText
			:	this.m_sel.toString());
		this._SetLinkText(linkText);
	}

	this._SetLinkText = function(linkText) {
		try {
			window.InsertLink.document.linkForm.linkText.value = linkText;
			window.InsertLink.document.linkForm.id = this.GetId();
		} catch (e) {
			Pause(1000);
			this._SetLinkText(linkText);
		}
	}

	this.HideAll = function() {
		this.HidePalette();
		this.HideSmiles();
	}

	///////////////////////////////////////////////////////////////////////////
	// Privates:

	this._SaveToFields = function(xhtml) {
		var result = 0;
		for (i = 0; i<this.m_fields.length; ++i) {
			var f = document.getElementById(this.m_fields[i]);
			if (f) {
				f.value = xhtml;
				result++;
			}
		}
		return result;
	}

	this._GetDesignModeParent = function() {
		return this.m_doc;
	}

	this._SetRange = function() {
		this.m_sel = null;
		if (document.all) {
			var selection = this.m_doc.selection;
			if (selection!=null) {
				this.m_sel = selection.createRange();
			}
		} else {
			var selection = this.m_editor.getSelection();
			this.m_sel = selection.getRangeAt(selection.rangeCount-1).cloneRange();
		}
		if (this.m_sel==null) {
			alert("selection == null");
		}
		return this.m_sel!=null;
	}

	this._ShowHidePalette = function(parentControl, cmd) {
		if (this.m_framePalette && this._SetRange()) {
			if (this.m_framePalette.style.visibility!="visible") {
				var manager = new ModuleWysiwygPaletteManager(
					this, this.m_framePalette.contentWindow, cmd, "#cccccc");
				this._ShowFrame(
					this.m_framePalette, parentControl, manager);
				this.m_openedPaletteCmd = cmd;
				return true;
			} else if (this.m_openedPaletteCmd && this.m_openedPaletteCmd!=cmd) {
				this.HidePalette();
				this._ShowHidePalette(parentControl, cmd);
			} else {
				this.HidePalette();
			}
		}
		return false;
	}

	this._ShowFrame = function(frame_, parentControl, manager) {
		if (frame_.style.visibility!="visible") {
			this.HideAll();
			this._InitFrame(frame_, parentControl, manager);
			frame_.style.display = "block";
			frame_.style.visibility = "visible";
			SetLeft(parentControl, frame_, 0);
			SetTop(parentControl, frame_, parentControl.height-1);
			return true;
		}
		return false;
	}

	this._InitFrame = function(frame_, parentControl, manager) {
		var backgroundColor = "";
		var borderColor = "";
		var font = "";
		var fontSize_ = "";
		var fontColor_ = "";
		if (this.m_stylerToolbar.IsOk()) {
			var style_ = this.m_stylerToolbar.GetStyle();
			backgroundColor = style_.backgroundColor;
			borderColor = style_.borderTopColor;
			font = style_.fontFamily;
			fontSize_ = style_.fontSize;
			fontColor_ = style_.color;
		}
		manager.AssignFont(font, fontSize_, fontColor_);
		manager.AssignColors(
			backgroundColor, borderColor, parentControl.width);
	}

	this.InitDocument = function() {
		this.m_doc = this.m_editor.document;
	}

	this._HideFrame = function(frameObj) {
		if (frameObj) {
			frameObj.style.visibility = "hidden";
			frameObj.style.display = "none";
		}
	}

	///////////////////////////////////////////////////////////////////////////
	// Construct:

	if (document.all) {
		this.m_frame = document.frames[this.GetId()];
		this.m_editor = this.m_frame;
	} else {
		this.m_frame = document.getElementById(this.GetId());
		this.m_editor = this.m_frame.contentWindow;
	}
	this.InitDocument();
	ModuleWysiwygEditorOnLoad = window.onload;
	window.onload = ModuleWysiwygEditorDocumentOnLoad;
}

function ModuleWysiwygEditorDocumentOnLoad(event) {
	if (typeof(ModuleWysiwygEditorOnLoad) != 'undefined') {
		ModuleWysiwygEditorOnLoad();
	}
	isModuleWysiwygEditorLoaded = true;
}

function ModuleWysiwygEditorFill(editorId, content, readOnly, delay) {
	var editor = _moduleWysiwyg.GetEditor(editorId);
	if (!editor) {
		return;
	}
	if (!readOnly) {
		try {
			if (!editor.IsFrameLoaded()) {
				setTimeout(
					"ModuleWysiwygEditorFill('"+editorId+"', '"+content+"', "+readOnly+", "+delay+");",
					delay);
				return;
			}
			editor.SetDesignModeOn();
		} catch (e) {
			try {
				editor.SetDesignModeOn();
			} catch (e) {
				alert("Error initialization \""+e+"\".");
				return;
			}
		}
	}
	try {
		editor.InitDocument();
		editor.m_doc.open();
		editor.m_doc.write(content);
		editor.m_doc.close();
	} catch (e) {
		alert("Error preloading content \""+e+"\".");
		return;
	}
	if (_moduleWysiwyg.IsGecko() && !readOnly) {
		editor.m_doc.addEventListener("keypress", ModuleWysiwygKeyPressGecko, true);
	}
	var re = new RegExp("^(.+)\/+([^/]+)$", "i");
	re.test(document.location);
	var reImg = new RegExp("^"+RegExp.$1+"\/+(.+)$", "i");
	var path = _moduleWysiwyg.GetImagesStorageDomain(); //+this.m_wysiwyg.ImagesStorageHttpFolder();
	editor.m_imagesSrcsBackup = Array();
	var allImages = editor.m_doc.getElementsByTagName('IMG');
	for (var i = 0; i<allImages.length; ++i) {
		if (reImg.test(allImages[i].src)) {
			editor.m_imagesSrcsBackup.push(new ImageBackup(allImages[i], RegExp.$1));
			allImages[i].src = path+RegExp.$1;
		}
	}
	return;
}