<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:template match="FORM[@FormMode='WithoutTags']">
	<xsl:call-template name="FormIntro"/>
</xsl:template>

<xsl:template match="FORM">
	<form enctype="multipart/form-data">
		<xsl:if test="INPUT[TYPE='WYSIWYG'] or ONSUBMIT">
			<xsl:attribute name="onsubmit">
				<xsl:apply-templates select="INPUT[TYPE='WYSIWYG']" mode="Action"/>
				<xsl:value-of select="ONSUBMIT"/>
			</xsl:attribute>
		</xsl:if>
		<xsl:apply-templates select="METHOD|ACTION|NAME|TARGET"/>
		<xsl:call-template name="FormIntro"/>
	</form>
</xsl:template>

<xsl:template name="FormIntro">
	<xsl:apply-templates select="INPUT[TYPE='HIDDEN']"/>
	<xsl:apply-templates select="INPUT[TYPE='WYSIWYG']" mode="Include"/>
	<xsl:call-template name="MODULE-FORM">
		<xsl:with-param name="module_form_inputs" select="INPUT[TYPE!='HIDDEN']"/>
		<xsl:with-param name="module_form_buttons" select="BUTTON"/>
	</xsl:call-template>
</xsl:template>

<xsl:template match="INPUT[TYPE='WYSIWYG']" mode="Action">
	<xsl:text>ModuleWysiwygAction();</xsl:text>
</xsl:template>

<xsl:template match="FORM/METHOD|FORM/ACTION|FORM/NAME|FORM/TARGET">
	<xsl:attribute name = "{name()}">
		<xsl:value-of select = "." />
	</xsl:attribute>
</xsl:template>

<xsl:template match="INPUT[TYPE='WYSIWYG']" mode="Include">
	<script type="text/javascript" language="javascript" src="{HTTP-PATH}js/modulewysiwyg.js"/>
	<script type="text/javascript" language="javascript" src="{HTTP-PATH}js/modulewysiwygeditor.js"/>
	<script type="text/javascript" language="javascript" src="{HTTP-PATH}js/modulewysiwyg_helpers.js"/>
	<script type="text/javascript" language="javascript" src="{HTTP-PATH}js/modulewysiwyg_frames.js"/>
	<script type="text/javascript" language="javascript" src="{HTTP-PATH}js/html2xhtml.js"/>
	<link rel="stylesheet" type="text/css" href="{HTTP-PATH}pages/modulewysiwyg.css"/>
</xsl:template>

<!--Do not edit MODULE-FORM-INPUT template. It is used for site templates!!! -->
<xsl:template name="MODULE-FORM-INPUT">
	<xsl:param name="module_form_input"/>
	<xsl:if test="TYPE!='HIDDEN'">
		<xsl:call-template name="MODULE-FORM-INPUT-LAYOUT">
			<xsl:with-param name="module_form_title" select="TITLE"/>
			<xsl:with-param name="module_form_input_element" select="$module_form_input"/>
		</xsl:call-template>
	</xsl:if>
</xsl:template>
<!--Do not edit MODULE-FORM-INPUT template. It is used for site templates!!! -->

<xsl:template match="INPUT[TYPE='HIDDEN']">
	<input><xsl:call-template name="INPUT-ATTRIBUTE"/></input>
</xsl:template>

<xsl:template match="INPUT/TITLE">
		<xsl:call-template name="MODULE-FORM-INPUT-TITLE">
			<xsl:with-param name="module_form_input_title" select="."/>
			<xsl:with-param name="module_form_input_required" select="../REQUIRED"/>
		</xsl:call-template>
</xsl:template>

<xsl:template match="INPUT/REQUIRED">
	<xsl:call-template name="MODULE-FORM-INPUT-REQUIRED">
		<xsl:with-param name="module_form_input_required_symbol">*</xsl:with-param>
	</xsl:call-template>
</xsl:template>

<xsl:template match="INPUT[TYPE='TEXT' or TYPE='PASSWORD']">
	<input>
		<xsl:call-template name="INPUT-ATTRIBUTE"/>
		<xsl:call-template name="MODULE-FORM-INPUT-DECORATION"/>
	</input>
</xsl:template>

<xsl:template match="INPUT[TYPE='TEXTAREA']" >
	<textarea>
		<xsl:call-template name="INPUT-ATTRIBUTE"/>
		<xsl:call-template name="MODULE-FORM-INPUT-DECORATION"/>
		<xsl:value-of select = "VALUE" />
	</textarea>
</xsl:template>

<xsl:template match="INPUT[TYPE='SELECT']" >
	<select>
		<xsl:call-template name="INPUT-ATTRIBUTE"/>
		<xsl:call-template name="MODULE-FORM-INPUT-DECORATION"/>
		<xsl:apply-templates select = "ITEM"/>
	</select>
</xsl:template>

<xsl:template match="INPUT[TYPE='SELECT']/ITEM" >
	<option value="{VALUE}">
		<xsl:apply-templates select="@SELECTED"/>
		<xsl:value-of select="TITLE"/>
	</option>
</xsl:template>

<xsl:template match="INPUT[TYPE='SELECT']/ITEM/@SELECTED" >
	<xsl:attribute name="selected"/>
</xsl:template>

<xsl:template match="INPUT[TYPE='WYSIWYG']" >
	<xsl:param name="WysiwygEditorId" select="generate-id()"/>
	<xsl:param name="WysiwygEditor">
		<xsl:text>editor_</xsl:text>
		<xsl:value-of select="$WysiwygEditorId"/>
	</xsl:param>
	<xsl:param name="Toolbar">
		<xsl:text>toolbar_</xsl:text>
		<xsl:value-of select="$WysiwygEditorId"/>
	</xsl:param>
	<xsl:param name="PaletteFrame">
		<xsl:text>palette_</xsl:text>
		<xsl:value-of select="$WysiwygEditorId"/>
	</xsl:param>
	<xsl:param name="SmilesFrame">
		<xsl:text>smiles_</xsl:text>
		<xsl:value-of select="$WysiwygEditorId"/>
	</xsl:param>
	<xsl:param name="HiddenId">
		<xsl:text>field_</xsl:text>
		<xsl:value-of select="$WysiwygEditorId"/>
	</xsl:param>
	<xsl:variable name="CommonPath" select="HTTP-PATH"/>
	<xsl:variable name="IncludesPath"><xsl:value-of select="$CommonPath"/>pages/</xsl:variable>
	<xsl:variable name="ImagesPath"><xsl:value-of select="$CommonPath"/>images/</xsl:variable>
	<xsl:variable name="TableWidth">100%</xsl:variable>
	<xsl:variable name="height">100%</xsl:variable>
	<xsl:variable name="framewidth">100</xsl:variable>
	<script language="JavaScript" type="text/javascript">
		var <xsl:value-of select="$WysiwygEditor"/>=null;
	</script>
	<table class="mwBase" cellpadding="2" cellspacing="0" style="width: {$TableWidth};">
		<tr>
			<td class="mwToolbar" id="{$Toolbar}">
				<div class="mwToolbarBlock">
					<select class="mwToolbarBut" onchange="{$WysiwygEditor}.UseFont(this,'fontname');">
						<option value="Font" selected="true">[Font]</option>
						<option value="Arial, Helvetica, sans-serif">Arial</option>
						<option value="Courier New, Courier, mono">Courier New</option>
						<option value="Times New Roman, Times, serif">Times New Roman</option>
						<option value="Verdana, Arial, Helvetica, sans-serif">Verdana</option>
					</select>
					<select class="mwToolbarBut" unselectable="on" onchange="{$WysiwygEditor}.UseFont(this,'fontsize');">
						<option value="Size">[Size]</option>
						<option value="1">1</option>
						<option value="2">2</option>
						<option value="3">3</option>
						<option value="4">4</option>
						<option value="5">5</option>
						<option value="6">6</option>
						<option value="7">7</option>
					</select>
					<img class="mwToolbarSep" src="{$ImagesPath}blackdot.gif" width="1" height="20" border="0" alt=""/>
				</div>
				<div class="mwToolbarBlock">
					<img class="mwToolbarButImg" src="{$ImagesPath}undo.gif" alt="Undo" title="Undo" onClick="{$WysiwygEditor}.ExecCommand('undo',null)"/>
					<img class="mwToolbarButImg" src="{$ImagesPath}redo.gif" alt="Redo" title="Redo" onClick="{$WysiwygEditor}.ExecCommand('redo',null)"/>
					<img class="mwToolbarSep" src="{$ImagesPath}blackdot.gif" width="1" height="20" border="0" alt=""/>
				</div>
				<div class="mwToolbarBlock">
					<img class="mwToolbarButImg" src="{$ImagesPath}bold.gif" alt="Bold" title="Bold" onClick="{$WysiwygEditor}.ExecCommand('bold',null);"/>
					<img class="mwToolbarButImg" src="{$ImagesPath}italic.gif" alt="Italic" title="Italic" onClick="{$WysiwygEditor}.ExecCommand('italic',null)"/>
					<img class="mwToolbarButImg" src="{$ImagesPath}underline.gif" alt="Underline" title="Underline" onClick="{$WysiwygEditor}.ExecCommand('underline',null)"/>
					<img class="mwToolbarSep" src="{$ImagesPath}blackdot.gif" width="1" height="20" border="0" alt=""/>
				</div>
				<div class="mwToolbarBlock">
					<img class="mwToolbarButImg" src="{$ImagesPath}left_just.gif" alt="Align Left" title="Align Left" onClick="{$WysiwygEditor}.ExecCommand('justifyleft',null)"/>
					<img class="mwToolbarButImg" src="{$ImagesPath}centre.gif" alt="Center" title="Center" onClick="{$WysiwygEditor}.ExecCommand('justifycenter',null)"/>
					<img class="mwToolbarButImg" src="{$ImagesPath}right_just.gif" alt="Align Right" title="Align Right" onClick="{$WysiwygEditor}.ExecCommand('justifyright',null)"/>
					<img class="mwToolbarButImg" src="{$ImagesPath}justifyfull.gif" alt="Justify Full" title="Justify Full" onclick="{$WysiwygEditor}.ExecCommand('justifyfull',null)"/>
					<img class="mwToolbarSep" src="{$ImagesPath}blackdot.gif" width="1" height="20" border="0" alt=""/>
				</div>
				<div class="mwToolbarBlock">
					<img class="mwToolbarButImg" src="{$ImagesPath}hr.gif" alt="Horizontal Rule" title="Horizontal Rule" onClick="{$WysiwygEditor}.ExecCommand('inserthorizontalrule',null)"/>
					<img class="mwToolbarSep" src="{$ImagesPath}blackdot.gif" width="1" height="20" border="0" alt=""/>
				</div>
				<div class="mwToolbarBlock">
					<img class="mwToolbarButImg" src="{$ImagesPath}numbered_list.gif" alt="Ordered List" title="Ordered List" onClick="{$WysiwygEditor}.ExecCommand('insertorderedlist',null)"/>
					<img class="mwToolbarButImg" src="{$ImagesPath}list.gif" alt="Unordered List" title="Unordered List" onClick="{$WysiwygEditor}.ExecCommand('insertunorderedlist',null)"/>
					<img class="mwToolbarButImg" src="{$ImagesPath}outdent.gif" alt="Outdent" title="Outdent" onClick="{$WysiwygEditor}.ExecCommand('outdent',null)"/>
					<img class="mwToolbarButImg" src="{$ImagesPath}indent.gif" alt="Indent" title="Indent" onClick="{$WysiwygEditor}.ExecCommand('indent',null)"/>
					<img class="mwToolbarButImg" src="{$ImagesPath}textcolor.gif" alt="Text Color" title="Text Color" onClick="{$WysiwygEditor}.ShowHidePaletteForecolor(this)"/>
					<img class="mwToolbarButImg" src="{$ImagesPath}bgcolor.gif" alt="Background Color" title="Background Color" onClick="{$WysiwygEditor}.ShowHidePaletteBackground(this)"/>
					<img class="mwToolbarSep" src="{$ImagesPath}blackdot.gif" width="1" height="20" border="0" alt=""/>
					<iframe width="164" height="106" id="{$PaletteFrame}" marginwidth="0" marginheight="0" scrolling="no" style="display: none; visibility: hidden; position: absolute; border: none;" frameborder="0"/>
				</div>
				<div class="mwToolbarBlock">
					<img class="mwToolbarButImg" src="{$ImagesPath}smiley.gif" alt="Smiles" title="Smiles" onClick="{$WysiwygEditor}.ShowHideSmiles(this)"/>
					<img class="mwToolbarButImg" src="{$ImagesPath}hyperlink.gif" alt="Insert Link" title="Insert Link" onClick="{$WysiwygEditor}.ShowHideInsertLink('link')"/>
					<img class="mwToolbarButImg" src="{$ImagesPath}image.gif" alt="Add Image" title="Add Image" onClick="{$WysiwygEditor}.ShowHideInsertImage('image')"/>
					<iframe width="80" height="120" id="{$SmilesFrame}" marginwidth="0" marginheight="0" scrolling="no" style="display: none; visibility: hidden; position: absolute; border: none;" frameborder="0"/>
				</div>
			</td>
		</tr>
		<tr>
			<td>
				<input type="hidden" id="{$HiddenId}" name="{NAME}">
					<xsl:value-of select="VALUE"/>
				</input>
				<iframe src="{$IncludesPath}blank.html" id="{$WysiwygEditorId}" height="{$height}" class="SB_Style_gen_title1" frameborder="0">
					<xsl:attribute name="width">
						<xsl:choose>
							<xsl:when test="$browser='MSIE'"><xsl:value-of select="$framewidth - 1"/>%</xsl:when>
							<xsl:otherwise><xsl:value-of select="$framewidth"/>%</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
				</iframe>
			</td>
		</tr>
	</table>
	<script language="JavaScript" type="text/javascript">
		<xsl:value-of select="$WysiwygEditor"/>=GetModuleWysiwygEditor('<xsl:value-of select="$CommonPath"/>','<xsl:value-of select="$ImagesPath"/>','<xsl:value-of select="$IncludesPath"/>','http://publish.abelyaev.plesk.ru/abel/css/styles.css','<xsl:value-of select="GUI-CONTROL-ATTRIBUTE[@NAME='IMAGES-STORAGE']"/>','foo','<xsl:value-of select="$WysiwygEditorId"/>','<xsl:value-of select="PARENT-ID"/>');
		<xsl:value-of select="$WysiwygEditor"/>.AttachField('<xsl:value-of select="$HiddenId"/>',true,false);
		<xsl:value-of select="$WysiwygEditor"/>.SetPaletteFrame('<xsl:value-of select="$PaletteFrame"/>');
		<xsl:value-of select="$WysiwygEditor"/>.SetSmilesFrame('<xsl:value-of select="$SmilesFrame"/>');
		<xsl:value-of select="$WysiwygEditor"/>.SetToolbar('<xsl:value-of select="$Toolbar"/>');
	</script>
</xsl:template>

<xsl:template name="INPUT-ATTRIBUTE">
	<xsl:attribute name="TYPE">
		<xsl:value-of select="TYPE"/>
	</xsl:attribute>
	<xsl:apply-templates select="NAME|VALUE|ONCHANGE"/>
</xsl:template>

<xsl:template match="INPUT/NAME|INPUT/TYPE|INPUT/VALUE|INPUT/ONCHANGE">
	<xsl:attribute name = "{name()}"><xsl:value-of select = "."/></xsl:attribute>
</xsl:template>

<xsl:template match="BUTTON">
	<xsl:call-template name="MODULE-FORM-BUTTON">
		<xsl:with-param name="module_form_button_title" select="TITLE"/>
		<xsl:with-param name="module_form_button_name" select="NAME"/>
		<xsl:with-param name="module_form_button_type" select="TYPE"/>
		<xsl:with-param name="module_form_button_actions" select="ONCLICK"/>
	</xsl:call-template>
</xsl:template>

<!--Do not edit MODULE-FORM-BUTTON-ACTIONS template. It is used for site templates!!! -->
<xsl:template name="MODULE-FORM-BUTTON-ACTIONS">
	<xsl:param name="module_form_button_additional_actions"/>
	<xsl:param name="module_form_button_native_actions"/>
	<xsl:if test="$module_form_button_additional_actions != '' or $module_form_button_native_actions != ''">
		<xsl:attribute name = "onclick">
			<xsl:value-of select="$module_form_button_additional_actions" disable-output-escaping="yes"/>
			<xsl:value-of select="$module_form_button_native_actions" disable-output-escaping="yes"/>
		</xsl:attribute>
	</xsl:if>
</xsl:template>
<!--Do not edit MODULE-FORM-BUTTON-ACTIONS template. It is used for site templates!!! -->

</xsl:stylesheet>